@@ -2,7 +2,7 @@ package Plack::Handler::CLI;
 use 5.008_001;
 use Any::Moose;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use IO::Handle  (); # autoflush
 use Plack::Util ();
@@ -85,9 +85,10 @@ sub run {
         }
     }
 
-    my $path_info = join '/', map { _uri_escape($_) } @argv;
+    my $path_info = '/' . join '/', map { _uri_escape($_) } @argv;
     my $query     = join ';', @params;
-    my $uri       = 'http://localhost/' . $path_info;
+
+    my $uri       = 'http://localhost' . $path_info;
     $uri .= "?$query" if length($query);
 
     my %env = (
@@ -179,7 +180,7 @@ Plack::Handler::CLI - Command line interface to PSGI applications
 
 =head1 VERSION
 
-This document describes Plack::Handler::CLI version 0.02.
+This document describes Plack::Handler::CLI version 0.03.
 
 =head1 SYNOPSIS
 
